# intracktive

[![PyPI - Version](https://img.shields.io/pypi/v/intracktive.svg)](https://pypi.org/project/intracktive)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intracktive.svg)](https://pypi.org/project/intracktive)

-----

## Installation

```console
pip install intracktive
```

## License

`intracktive` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
